@@ -8,7 +8,7 @@ licence: https://opensource.org/licenses/MIT
 import logging
 from functools import cache
 
-from .encoding import is_graphical, is_whitespace
+from .encoding import is_graphical, is_blank
 from .labels import Codepoint, Char, Tag, to_label
 from .raster import Raster, NOT_SET, turn_method
 from .properties import (
@@ -299,7 +299,7 @@ class Glyph:
             codepoint=codepoint,
             char=char,
             tag=tag,
-            comment=comment,
+            comment=comment or '',
             _0=_0, _1=_1,
             **properties
         )
@@ -335,7 +335,7 @@ class Glyph:
         # use codepage to find char if not set
         if char_from and (overwrite or not self.char):
             char = char_from.char(*labels)
-            if match_whitespace and self.is_blank() and char and not is_whitespace(char):
+            if match_whitespace and self.is_blank() and char and not is_blank(char):
                 return self
             if match_graphical and not self.is_blank() and char and not is_graphical(char):
                 return self
